@@ -1,15 +1,11 @@
 int myrand(int max);
-void * mymalloc(int size, char *what);
-void * myrealloc(void *oldp, int newsize, char *what);
-void myfree(void *p);
-char * mystrdup(char *in, char *what);
 char * read_line_fd(int fd);
 char * get_load(void);
 int get_vmsize(pid_t pid);
 void stop_process(int pid);
 void delete_array(char **list, int n);
 int find_char_offset(char *str, char what);
-int file_info(char *filename, off64_t *file_size, time_t *ts);
+int file_info(char *filename, off64_t *file_size, time_field_t tft, time_t *ts, mode_t *mode);
 char * convert_regexp_error(int error, const regex_t *preg);
 char check_date(void);
 ssize_t WRITE(int fd, char *whereto, size_t len);
@@ -23,6 +19,22 @@ void dump_mem(int sig);
 #endif
 char *abbreviate_filesize(off64_t fsize);
 int file_exist(char *filename);
+char * shorten_filename(char *in, int max_len);
+double get_ts(void);
+int find_path_max(void);
+int match_files(char *search_for, char **path, char ***found, char **isdir);
+void setup_for_childproc(int fd, char close_fd_0, char *term);
+int open_null(void);
+void init_children_reaper(void);
+int execute_program(char *execute, char bg);
+void check_exited_children(void);
+void free_re(re *cur_re);
+char * find_most_recent_file(char *filespec, char *cur_file);
+char zerotomin(char c);
+char *find_next_par(char *start);
+int mydup(int old_fd);
+char * term_t_to_string(term_t term);
+void get_now_ts(char *format_str, char *dest, int dest_size);
 
 #define min(x, y) ((x)<(y)?(x):(y))
 #define max(x, y) ((x)>(y)?(x):(y))
